searchData={"items":[{"type":"module","title":"Sufx","doc":"A generic string fuzzy matching utility.\n\nPlease see examples in the [readme file](readme.html).","ref":"Sufx.html"},{"type":"function","title":"Sufx.compress/1","doc":"Compresses the given tree to a more memory and CPU efficient form.\n\nWhile memory footprint is optimized, and searches will be faster, a compressed\ntree does not support further insertion.","ref":"Sufx.html#compress/1"},{"type":"function","title":"Sufx.decompress/1","doc":"Returns the original tree before compression.","ref":"Sufx.html#decompress/1"},{"type":"function","title":"Sufx.insert/3","doc":"Inserts a new phrase/value pair in an existing tree.\n\nThis function does not support compressed trees.","ref":"Sufx.html#insert/3"},{"type":"function","title":"Sufx.new/0","doc":"Creates an new, empty suffix tree.","ref":"Sufx.html#new/0"},{"type":"function","title":"Sufx.new/1","doc":"Creates a new tree from tokens.\n\nTokens are phrase/value pairs where the phrase is a string and the value any\nterm.","ref":"Sufx.html#new/1"},{"type":"function","title":"Sufx.search/2","doc":"Matches all phrases in the tree with the given pattern and return all values\nassociated with successfully matched phrases.\n\nReturns an empty list if the given pattern is an empty string.","ref":"Sufx.html#search/2"},{"type":"function","title":"Sufx.search_score/2","doc":"This function has the same behaviour as `search/2` but the results are wrapped\nin a tuple where the first element is the search result value and the second\nelement is the score.\n\nNote that the results are not ordered by score, and multiple results can have\nthe same score.\n\nSee `sort_by_score/1`.","ref":"Sufx.html#search_score/2"},{"type":"function","title":"Sufx.sort_by_score/1","doc":"Returns the given list of scored results sorted by descending score order.\n\nNote that the order may slightly differ from an implementation with\n`Enum.sort_by/3` due to optimizations.\n\nThe function does nothing special and you are totally free to sort the results\nin any other way.","ref":"Sufx.html#sort_by_score/1"},{"type":"type","title":"Sufx.pattern/0","doc":"","ref":"Sufx.html#t:pattern/0"},{"type":"type","title":"Sufx.phrase/0","doc":"","ref":"Sufx.html#t:phrase/0"},{"type":"type","title":"Sufx.t/0","doc":"","ref":"Sufx.html#t:t/0"},{"type":"type","title":"Sufx.tokens/0","doc":"","ref":"Sufx.html#t:tokens/0"},{"type":"extras","title":"Sufx","doc":"# Sufx\n\nThis library provides simple fuzzy matching of strings given a search pattern.\nPatterns are a suite of characters without any special meaning, simply put, a\nstring.\n\nThis resembles VS Code fuzzy finder, with a very basic scoring algorithm.\n\nThe implemenation is based on a suffix tree, though this library is not a\ngeneric suffix tree or suffix trie implementation.","ref":"readme.html"},{"type":"extras","title":"Example - Sufx","doc":"A tree is defined by a map of tokens, where each key is a string and each value\nany term of your chosing. Here for instance we are building a tree to help find\ngeneral domain topics. The values are composed of a domain (_programming_,\n_physics_, …) and the topic name. The search will be performed on the topic\nnames so we use them for keys.\n\n```elixir\ntree =\n  %{\n    \"algorithm\" => {:programming, \"algorithm\"},\n    \"wavelength\" => {:physics, \"wavelength\"},\n    \"allegory\" => {:philosophy, \"allegory\"},\n    \"novel\" => {:litterature, \"novel\"}\n  }\n  |> Sufx.new()\n  |> Sufx.compress()\n```\n\nNow the tree is ready to use, we can search, for instance with the `\"alg\"`\nstring.\n\n```elixir\nresults = Sufx.search(tree, \"alg\")\nIO.inspect(results, label: \"results\")\n```\n\nThe code above would print the following results:\n\n```\nresults: [\n  physics: \"wavelength\",\n  philosophy: \"allegory\",\n  programming: \"algorithm\"\n]\n```\n\nThe matches were computed like so:\n\n* w**a**ve**l**en**g**th\n* **al**le**g**ory\n* **alg**orithm\n\nThe library supports a simplistic scoring mechanism based on the length of the matched patterns. With the following code:\n\n```elixir\nresults =\n  tree\n  |> Sufx.search_score(\"alg\")\n  |> Sufx.sort_by_score()\n\nIO.inspect(results, label: \"results\")\n```\n\nWe would get the following results:\n\n```\nresults: [\n  {{:programming, \"algorithm\"}, 3},\n  {{:philosophy, \"allegory\"}, 2},\n  {{:physics, \"wavelength\"}, 1}\n]\n```\n\nWhen building the tree, the key does not have to be part of the value. For instance to match user posts in a database, where the user has posts like these:\n\n```elixir\ndocuments =\n  [\n    %{id: 1001, title: \"Collectible card game are great!\"},\n    %{id: 1002, title: \"Discussion on suffixes\"},\n    %{id: 1003, title: \"Cats for the greater good\"},\n    %{id: 1004, title: \"Cats considered harmul!\"}\n  ]\n```\n\nA tree could be built and searched like so:\n\n```elixir\ntree =\n  documents\n  |> Enum.reduce(Sufx.new(), fn post, tree ->\n    Sufx.insert(tree, post.title, post.id)\n  end)\n  |> Sufx.compress()\n\nresults = Sufx.search_score(tree, \"cgg\")\n```\n\nAs we did not include the searchable strings in our values, but just the post IDs, this is what we expect:\n\n```\nresults: [{1001, 1}, {1003, 1}]\n```\n\nAnd `Sufx.search_score(tree, \"CCG\")` would yield `[{1001, 1}]`.","ref":"readme.html#example"},{"type":"extras","title":"Installation - Sufx","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `sufx` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:sufx, \"~> 0.1.0\"},\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}